@@ -4,10 +4,14 @@ import re
 from jose import jwt
 import requests
 from time import sleep
-from .version import api_version
+from .version import version_tuple
 from tabulate import tabulate
 import textwrap
 
+
+# Define the API version
+api_version = f"{version_tuple[0]}.{version_tuple[1]}"
+
 # Next imports are not dependancies, but if you have them installed, we'll use
 # them
 try:
@@ -76,7 +80,28 @@ API_URL = "https://www.swift.psu.edu/toop/submit_json.php"
 
 
 def convert_to_dt(value, isutc=False, outfunc=datetime):
-    """Convert various date formats to swiftdatetime"""
+    """Convert various date formats to swiftdatetime or datetime
+
+    Parameters
+    ----------
+    value : varies
+        Value to be converted.
+    isutc : bool, optional
+        Is the value in UTC, by default False
+    outfunc : datetime / swiftdatetime, optional
+        What format should the output be? By default datetime, can be
+        swiftdatetime
+
+    Returns
+    -------
+    datetime / swiftdatetime
+        Returned datetime / swiftdatetime object
+
+    Raises
+    ------
+    TypeError
+        Raised if incorrect format is given for conversion.
+    """
     if type(value) == str:
         if re.match(_datetime_regex, value):
             if "." in value:
@@ -111,7 +136,20 @@ def convert_to_dt(value, isutc=False, outfunc=datetime):
 
 
 def _tablefy(table, header=None):
-    """Simple HTML table generator."""
+    """Simple HTML table generator
+
+    Parameters
+    ----------
+    table : list
+        Data for table
+    header : list
+        Headers for table, by default None
+
+    Returns
+    -------
+    str
+        HTML formatted table.
+    """
 
     tab = "<table>"
     if header is not None:
